@@ -5,30 +5,38 @@ from expai.utils import generate_response
 
 
 class ExpaiLogin:
-    def __init__(self, email: str = None, user_pass: str = None, api_key: str = None, server_name: str = "http://api.expai.io:80"):
-        assert api_key is not None, "You must provide an api_key"
+    def __init__(self, email: str = None, user_pass: str = None, access_token: str = None, server_name: str = "https://api.expai.io:443"):
         assert email is not None, "Please, introduce your user id"
         assert user_pass is not None, "Please, introduce your password"
 
         self.server_name = server_name
-        self.api_key = api_key
         self.email = email
 
-        self.headers = {
-            'api_key': self.api_key,
-            'Content-Type': 'application/json'
-        }
+        if access_token is None:
+            self.headers = {
+                'Content-Type': 'application/json'
+            }
 
-        json = {
-            "email_des": email,
-            "password_des": user_pass
-        }
+            json = {
+                "email_des": email,
+                "password_des": user_pass
+            }
 
-        self.sess = requests.session()
-        response = self.sess.post(self.server_name + "/api/auth/login", headers=self.headers, json=json)
+            self.sess = requests.session()
+            response = self.sess.post(self.server_name + "/api/auth/login", headers=self.headers, json=json)
 
-        if not response.ok:
-            logging.error("Invalid credentials, please check them and try again. Thank you.")
+            if not response.ok:
+                logging.error("Invalid credentials, please check them and try again. Thank you.")
+
+            self.access_token = response.json().get('access_token')
+            self.headers['access_token'] = self.access_token
+
+        else:
+            self.access_token = access_token
+            self.headers = {
+                'Content-Type': 'application/json',
+                'access_token': access_token
+            }
 
     def project_list(self, search_by: str = None, exact_search: str = None):
         """
@@ -73,7 +81,7 @@ class ExpaiLogin:
         payload = {"project_name_des": project_name,
                    'project_description_des': project_description}
 
-        response = self.sess.request("GET", self.server_name + "/api/projects/create", headers=self.headers,
+        response = self.sess.request("POST", self.server_name + "/api/projects/create", headers=self.headers,
                                      json=payload)
 
         if response.ok:
@@ -114,7 +122,7 @@ class ExpaiLogin:
             project_id = self._get_project_id_from_name(project_name)
 
         if project_id is not None:
-            return ExpaiProject(project_id, self.api_key, self.headers, self.server_name, self.sess)
+            return ExpaiProject(project_id, self.access_token, self.headers, self.server_name, self.sess)
         else:
             logging.error("We could not find your project. Please, check your name or try using project_id as parameter")
             return None
